When analyzing or interpreting C3 gas exchange data, it is often useful to
estimate the relative limitations to assimilation that are due to stomatal
conductance, mesophyll conductance, and biochemistry. This can be done using
a framework first introduced by Grassi & Magnani (2005). In this framework,
the relative limitation due to stomatal conductance (ls) is
ls = [(g_t / g_sc) * (dAdC)] / [g_t + dAdC],
the relative limitation due to mesophyll conductance (lm) is
lm = [(g_t / g_mc) * (dAdC)] / [g_t + dAdC],
and the relative limitation due to biochemistry (lb) is
ln = [g_t] / [g_t + dAdC],
where g_sc is the stomatal conductance to CO2, g_mc is the
mesophyll conductance to CO2, gt = 1 / (1 / g_mc + 1 / g_sc) is the
total conductance to CO2, and dAdC is the partial derivative of the
net CO2 assimilation rate (An) with respect to the chloroplast CO2
concentration (Cc). These can be found in Equation 7 from Grassi &
Magnani (2005).
These equations were derived by assuming that CO2 assimilation is limited by
Rubisco activity; in other words, that the net CO2 assimilation rate is given
by
Ac = Vcmax * (Cc - Gamma_star) / (Cc + Km) - RL,
where Vcmax is the maximum Rubisco carboxylation rate,
Gamma_star is the CO2 compensation point in the absence of day
respiration, RL is the day respiration rate, Km is the effective
Michaelis-Menten constant for Rubisco carboxylation. In turn, Km is
given by Km = Kc * (1 + O / Ko), where Kc is the
Michaelis-Menten constant for carboxylation, Ko is the Michaelis-Menten
constant for oxygenation, and O is the oxygen concentration in the
chloroplast.
Under this assumption, it is possible to analytically determine the partial
derivative dAdC:
dAdC_rubisco = Vcmax * (Gamma_star + Km) / (Cc + Km)^2
In this case, the limitation due to "biochemistry" actually refers to
limitation due to the value of Vcmax. Note that sometimes this
derivative is estimated from the initial slope of a measured A-Ci curve rather
than calculated analytically. (See, for example, Pathare et al. (2023).)
However, we do not take that approach here. Also note that the value of
Vcmax can be estimated using different approaches. For example, Xiong
(2023) uses single-point gas exchange measurements. When possible, it would be
better to use an estimate from fitting an entire A-Ci curve, as shown in the
example below.
To understand the meaning of these limiting factors, note that simultaneously
making small fractional increases to g_sc, g_mc, and
Vcmax will generally cause an associated small fractional increase in
An. The limiting factors describe the fraction of the increase in
An that can be attributed to each of g_sc, g_mc, and
Vcmax. For example, ls = 0.2, lm = 0.3, lb = 0.5 would mean that
20 percent of the increase in An would be due to an increase in
stomatal conductance, 30 percent due to an increase in mesophyll conductance,
and 50 percent due to an increase in Vcmax. Note that ls,
lm, and lb always add up to 1.
Thus, when one of the factors is large, changes in the related parameter
produce relatively larger changes in the assimilation rate. In that case, it
can be said that that parameter is setting a large limit on the assimilation
rate. On the other hand, if a factor is small, small changes in the related
parameter produce relatively small changes in An, and therefore that
parameter is not setting a large limit on the assimilation rate.
It is also possible to calculate dAdC when assimilation is limited by
RuBP regeneration. In this case, we have
Aj = J * (Cc - Gamma_star) / (4 * Cc + 8 * Gamma_star) - RL,
where J is the RuBP regeneration rate, and the limitation due to
"biochemistry" actually refers to limitation due to the value of J
(rather than Vcmax. The same equations as before can be used to
calculate the limiting factors (ls, lm, lb), but the
partial derivative is now given by
dAdC_j = J * Gamma_star * 12 / (4 * Cc + 8 * Gamma_star)^2.
Most users will want the limitations assuming Rubisco-limited assimilation.
However, if j_column_name is not NULL, values of J will
be used to calculate the limiting factors assuming RuBP-regeneration-limited
assimilation. For an example of how these additional factors can be used, see
Sakoda et al. (2021).
References:
Grassi, G. & Magnani, F. "Stomatal, mesophyll conductance and biochemical
limitations to photosynthesis as affected by drought and leaf ontogeny in ash
and oak trees." Plant, Cell & Environment 28, 834–849 (2005)
[tools:::Rd_expr_doi("10.1111/j.1365-3040.2005.01333.x")].
Pathare, V. S. et al. "Altered cell wall hydroxycinnamate composition impacts
leaf- and canopy-level CO2 uptake and water use in rice." Plant Physiology
kiad428 (2023) [tools:::Rd_expr_doi("10.1093/plphys/kiad428")].
Xiong, D. "Leaf anatomy does not explain the large variability of mesophyll
conductance across C3 crop species." The Plant Journal 113, 1035–1048 (2023)
[tools:::Rd_expr_doi("10.1111/tpj.16098")].
Sakoda, K., Yamori, W., Groszmann, M. & Evans, J. R. "Stomatal, mesophyll
conductance, and biochemical limitations to photosynthesis during induction."
Plant Physiology 185, 146–160 (2021)
[tools:::Rd_expr_doi("10.1093/plphys/kiaa011")].