# Read an example Licor file included in the PhotoGEA package
licor_file <- read_gasex_file(
PhotoGEA_example_file_path('c3_aci_1.xlsx')
)
# Define a new column that uniquely identifies each curve
licor_file[, 'species_plot'] <-
paste(licor_file[, 'species'], '-', licor_file[, 'plot'] )
# Organize the data
licor_file <- organize_response_curve_data(
licor_file,
'species_plot',
c(9, 10, 16),
'CO2_r_sp'
)
# Estimate variance in measured A values
licor_file <- estimate_licor_variance(
licor_file,
sd_CO2_r = 1,
sd_CO2_s = 0.1,
sd_flow = 0.2,
sd_H2O_r = 0.5,
sd_H2O_s = 0.1
)
# Plot each component of the total variance of A
lattice::xyplot(
var_CO2_r + var_CO2_s + var_flow + var_H2O_r + var_H2O_s + var_A ~ Ci | species_plot,
data = licor_file$main_data,
type = 'b',
pch = 16,
auto = TRUE
)
# Plot the standard deviation of A
lattice::xyplot(
sd_A ~ Ci,
group = species_plot,
data = licor_file$main_data,
type = 'b',
pch = 16,
auto = TRUE
)
Run the code above in your browser using DataLab