The Ball-Berry model is a simple way to describe the response of a leaf's
stomata to its assimilation rate and local environmental conditions.
Specifically, it predicts stomatal conductance to water vapor using the
following equation:
gsw = bb_0 + bb_1 * A * h_s / C_s
where gsw is the stomatal conductance, A is the net assimilation
rate, h_s is the relative humidity at the leaf surface, and C_s
is the CO2 concentration at the leaf surface. The term A * h_s / C_s is
commonly referred to as the Ball-Berry index, while the intercept
(bb_0) and slope (bb_1) of the linear relationship are the
Ball-Berry parameters which describe the stomatal response.
Although this model is certainly an oversimplification, it does encode some
important stomatal responses. For example, when humidity is low, the stomata
close, reducing stomatal conductance. Likewise, if the CO2 concentration
around the leaf is depleted, the stomata open to allow more CO2 to diffuse
into the leaf's interior, increasing somatal conductance. For more information
about this model and some possible alternatives, see the following papers:
Ball, J. T., Woodrow, I. E. and Berry, J. A. "A Model Predicting
Stomatal Conductance and its Contribution to the Control of
Photosynthesis under Different Environmental Conditions." in "Progress
in Photosynthesis Research: Volume 4" (1986)
[tools:::Rd_expr_doi("10.1007/978-94-017-0519-6_48")].
Tardieu, F. and Davies, W. J. "Integration of hydraulic and chemical
signalling in the control of stomatal conductance and water status of
droughted plants." Plant, Cell & Environment 16, 341–349 (1993).
[tools:::Rd_expr_doi("10.1111/j.1365-3040.1993.tb00880.x")].
Leuning, R. "A critical appraisal of a combined
stomatal-photosynthesis model for C3 plants." Plant, Cell &
Environment 18, 339–355 (1995)
[tools:::Rd_expr_doi("10.1111/j.1365-3040.1995.tb00370.x")].
Dewar, R. C. "The Ball–Berry–Leuning and Tardieu–Davies stomatal
models: synthesis and extension within a spatially aggregated picture
of guard cell function." Plant, Cell & Environment 25, 1383–1398 (2002).
[tools:::Rd_expr_doi("10.1046/j.1365-3040.2002.00909.x")].
Ball-Berry parameters are typically determined by measuring a Ball-Berry
curve, where one or more of the factors that influence the Ball-Berry index
is systematically varied across a range of values. At each value, care is
taken that net assimilation and stomatal conductance have reached their
steady-state values, and then those values are recorded. Then, a linear fit of
the experimentally observed stomatal conductances as a function of the
Ball-Berry index is performed to extract estimates for the Ball-Berry
intercept and slope.
This function uses lm to perform the fit.
This function assumes that replicate_exdf represents a single
Ball-Berry curve. To fit multiple curves at once, this function is often used
along with by.exdf and consolidate.