Parameters describing the temperature response of important C3 photosynthetic
parameters, intended to be passed to the
calculate_temperature_response function.
c3_temperature_param_bernacchiList with 12 named elements that each represent a variable whose temperature-dependent value can be calculated using an Arrhenius equation, Johnson-Eyring-Williams equation, or a polynomial equation:
Gamma_star_at_25: The value of chloroplastic CO2 concentration
at which CO2 gains from Rubisco carboxylation are exactly balanced by
CO2 losses from Rubisco oxygenation (Gamma_star) at 25
degrees C.
Gamma_star_norm: Gamma_star normalized to its value at
25 degrees C.
gmc_norm: The mesophyll conductance to CO2 diffusion
(gmc) normalized to its value at 25 degrees C.
J_norm: The electron transport rate (J) normalized to
its value at 25 degrees C.
Kc_at_25: The Michaelis-Menten constant for rubisco
carboxylation (Kc) at 25 degrees C.
Kc_norm: Kc normalized to its value at 25 degrees C.
Ko_at_25: The Michaelis-Menten constant for rubisco oxygenation
(Ko) at 25 degrees C.
Ko_norm: Ko normalized to its value at 25 degrees C.
RL_norm: The rate of non-photorespiratory CO2 release in the
light (RL) normalized to its value at 25 degrees C.
Tp_norm: The maximum rate of triose phosphate utilization
(Tp) normalized to its value at 25 degrees C.
Vcmax_norm: The maximum rate of rubisco carboxylation
(Vcmax) normalized to its value at 25 degrees C.
Vomax_norm: The maximum rate of rubisco oxygenation
(Vomax) normalized to Vcmax at 25 degrees C.
In turn, each of these elements is a list with at least 2 named elements:
type: the type of temperature response
units: the units of the corresponding variable.