Temperature response parameters describing the temperature response of
important C4 photosynthetic parameters, intended to be passed to the
calculate_temperature_response function.
c4_temperature_param_vcList with 10 named elements that each represent a variable whose temperature-dependent value can be calculated using either an Arrhenius or Gaussian equation:
Vcmax_norm: The maximum rate of rubisco carboxylation
(Vcmax) normalized to its value at 25 degrees C.
Vpmax_norm: The maximum rate of PEP carboxylase activity
(Vpmax) normalized to its value at 25 degrees C.
RL_norm: The respiration rate (RL) normalized to the
value of Vcmax at 25 degrees C.
Kc: The Michaelis-Menten constant for rubisco carboxylation.
Ko: The Michaelis-Menten constant for rubisco oxygenation.
Kp: The Michaelis-Menten constant of PEP carboxylase.
gamma_star: Half the reciprocal of rubisco specificity.
ao: The ratio of solubility and diffusivity of O2 to CO2.
gmc_norm: The mesophyll conductance to CO2 diffusion normalized
to its value at 25 degrees C.
J_norm: The electron transport rate J normalized to its
value at 25 degrees C.
The J_norm parameter is calculated using a Gaussian function and
hence its corresponding list element is itself a list with 4 named elements:
type: the type of temperature response ('Gaussian')
optimum_rate: the largest value this parameter can take.
t_opt: the temperature where the optimum occurs in
degrees C.
sigma: the width of the Gaussian in degrees C.
units: the units of the corresponding variable.
Each of the remaining elements is a list with 4 named elements:
type: the type of temperature response ('Arrhenius')
c: the (dimensionless) Arrhenius scaling factor.
Ea: the activation energy in kJ / mol.
units: the units of the corresponding variable.