When analyzing or interpreting C3 gas exchange data, it is often useful to
estimate the relative limitations to assimilation that are due to stomatal
conductance or mesophyll conductance. This can be done using a framework first
introduced by Warren et al. (2003). In this framework, the relative limitation
due to stomatal conductance (ls) is
ls = (An_inf_gsc - A_modeled) / An_inf_gsc
and the relative limitation due to mesophyll conductance (lm) is
lm = (An_inf_gmc - A_modeled) / An_inf_gmc. These are equations 10 and
11 in Warren et al. (2003).
In these equations A_modeled is the net assimilation rate calculated
using the Farquhar-von-Caemmerer-Berry (FvCB) model at the measured value of
the chloroplast CO2 concentration (Cc). The other two assimilation
rates (An_inf_gsc and An_inf_gmc) are also calculated using the
FvCB model, but under different assumptions: An_inf_gsc assumes that
stomatal conductance is infinite while mesophyll conductance is as measured,
while An_inf_gmc assumes that mesophyll conductance is infinite while
stomatal conductance is as measured.
In other words, ls expresses the observed assimilation rate as a
fractional decrease relative to a hypothetical plant with infinite stomatal
conductance, while lm expresses the observed assimilation rate as a
fractional decrease relative to a hypothetical plant with infinite mesophyll
conductance.
For example, if lm = 0.4, this means that the observed assimilation
rate is 40 percet lower than a hypothetical plant with infinite mesophyll
conductance. If mesophyll conductance were to increase (all else remaining
the same), then lm would decrease. This is not the case with other
estimations of limiting factors, such as the one used in
calculate_c3_limitations_grassi. (See Leverett & Kromdijk for
more details.)
To actually calculate An_inf_gsc and An_inf_gmc, it is first
necessary to estimate the corresponding values of Cc that would occur
with infinite stomatal or mesophyll conductance. This can be done with a 1D
diffusion equation expressed using drawdown values:
Cc = Ca - drawdown_cs - drawdown_cm,
where drawdown_cs = Ca - Ci is the drawdown of CO2 across the stomata
(assuming infinite boundary layer conductance) and
drawdown_cm = Ci - Cc is the drawdown of CO2 across the mesophyll. If
one conductance is infinite, the corresponding drawdown becomes zero. Thus, we
have:
Cc_inf_gsc = Ca - 0 - (Ci - Cc) = Ca - Ci + Cc
and
Cc_inf_gmc = Ca - (Ca - Ci) - 0 = Ci,
where Cc_inf_gsc is the value of Cc that would occur with
infinite stomatal conductance and the measured mesophyll conductance, and
Cc_inf_gmc is the value of Cc that would occur with infinite
mesophyll conductance and the measured stomatal conductance.
Once values of Cc, Cc_inf_gsc, and Cc_inf_gmc, the
corresponding assimilation rates are calculated using
calculate_c3_assimilation, and then the limitation factors are
calculated as described above.
References:
Warren, C. R. et al. "Transfer conductance in second growth Douglas-fir
(Pseudotsuga menziesii (Mirb.)Franco) canopies." Plant, Cell & Environment 26,
1215–1227 (2003) [tools:::Rd_expr_doi("10.1046/j.1365-3040.2003.01044.x")].
Leverett, A. & Kromdijk, J. "The long and tortuous path towards improving
photosynthesis by engineering elevated mesophyll conductance."
[tools:::Rd_expr_doi("10.22541/au.170016201.13513761/v1")].