# Read an example Licor file included in the PhotoGEA package
licor_file <- read_gasex_file(
PhotoGEA_example_file_path('ball_berry_1.xlsx')
)
# In this example we will calculate temperature-dependent values of two
# parameters:
#
# - The `Kc` parameter (in units of `micromol mol^(-1)`) will be calculated
# using an Arrhenius function with scaling constant `c` = 38.05 and activation
# energy `Ea` = 79.43 kJ / mol.
#
# - The `Jmax` parameter (in units of `micromol m^(-2) s^(-1)) will be
# using a Gaussian function with optimal temperature `t_opt` = 43 degrees C
# and width `sigma` = 16 degrees C.
#
# So the `temperature_response_parameters` list will contain two elements,
# defined as follows:
trp <- list(
Kc = list(
type = 'Arrhenius',
c = 38.05,
Ea = 79.43,
units = 'micromol mol^(-1)'
),
Jmax = list(
type = 'Gaussian',
optimum_rate = 4,
t_opt = 43,
sigma = 16,
units = 'micromol m^(-2) s^(-1)'
)
)
# Now we can calculate the values of Kc and Jmax at the measured leaf
# temperatures recorded in the log file
licor_file <- calculate_temperature_response(licor_file, trp)
licor_file$units$Kc # View the units of the new `Kc` column
licor_file$categories$Kc # View the category of the new `Kc` column
licor_file[,'Kc'] # View the values of the new `Kc` column
licor_file$units$Jmax # View the units of the new `Jmax` column
licor_file$categories$Jmax # View the category of the new `Jmax` column
licor_file[,'Jmax'] # View the values of the new `Jmax` column
Run the code above in your browser using DataLab