Polynomial equations are often used to calculate the temperature dependence
of the rates of chemical reactions. For example, a second-order polynomial
could be given as follows:
(1) rate = R_0 + R_1 * T + R_2 * T^2
where R_0, R_1, and R_2 are the zeroth, first, and second
order coefficients and T is the temperature. Higher order polynomials
can also be defined, where an order-N polynomial is given by
(2) rate = R_0 + R_1 * T + R_2 * T^2 + ... + R_N * T^N
In general, an order-N polynomial has N coefficients, although
some of them may be zero.
In calculate_temperature_response_polynomial, the coefficients
(coef) and units (units) for a variable must be specified as
elements of a list, which itself is a named element of
polynomial_parameters. The coefficients must be specified as a numeric
vector, where the ith element represents the ith coefficient.
For example, if a dimensionless variable called theta is calculated
according to theta = 0.352 + 0.022 * T - 3.4e-4 * T^2, the
polynomial_parameters argument could be supplied as follows:
list(theta = list(coef = c(0.352, 0.022, -3.4e-4), units = 'dimensionless')).
It is rare to directly specify the polynomial parameters; instead, it is more
typical to use one of the pre-set values such as those included in
jmax_temperature_param_bernacchi.