During photosynthetic gas exchange, there are separate fluxes of CO2 and H2O
flowing in and out of the leaf. These gases interact with each other and with
air, forming a ternary mixture. These interactions must be taken into account
when modeling carbon isotope discrimination. Typically this is done via
t, a ternary correction factor first introduced by Farquhar and
Cernusak (2012). Here we calculate t as described in Equations 9 and 10
from Ubierna et al. (2018):
t = alpha_ac * E / (2 * g_ac)
and
a_bar = (a_b * (C_a - C_s) + a_s * (C_s - C_i)) / (C_a - C_i),
where E is the transpiration rate, g_ac is the total conductance
to CO2 diffusion across the boundary layer and stomata in series, a_bar
is the weighted fractionation across the boundary layer and stomata in series,
a_b is the fractionation during diffusion through the boundary layer,
a_s is the fractionation during diffusion through the stomata,
C_a is the ambient CO2 concentration (in wet air), C_s is the
CO2 concentration (in wet air) at the leaf surface, and C_i is the CO2
concentration (in wet air) in the intercellular spaces.
alpha_ac is the overall fractionation during diffusion through air;
alpha_ac and a_bar are related according to an un-numbered
equation in Ubierna et al. (2018) that appears just after Equation 9:
alpha_ac = 1 + a_bar
References:
Farquhar, G. D. and Cernusak, L. A. "Ternary effects on the gas exchange of
isotopologues of carbon dioxide." Plant, Cell & Environment 35, 1221–1231
(2012) [tools:::Rd_expr_doi("10.1111/j.1365-3040.2012.02484.x")].
Ubierna, N., Holloway-Phillips, M.-M. and Farquhar, G. D. "Using Stable Carbon
Isotopes to Study C3 and C4 Photosynthesis: Models and Calculations." in
Photosynthesis: Methods and Protocols (ed. Covshoff, S.) 155–196 (Springer,
2018) [tools:::Rd_expr_doi("10.1007/978-1-4939-7786-4_10")].