# Interactively select a single file and get full file paths to all
# other files in the same directory that have the same extension
if (interactive()) {
file_paths <- choose_input_files()
}
# Interactively select one or more Licor Excel files and read each one to create
# a list of exdf objects
if (interactive() && .Platform$OS.type == "windows") {
lapply(choose_input_licor_files(), function(fname) {
read_gasex_file(fname, 'time')
})
}
# Interactively select one or more TDL data files and read each one to create a
# list of exdf objects
if (interactive() && .Platform$OS.type == "windows") {
lapply(choose_input_tdl_files(), function(fname) {
read_gasex_file(fname, 'TIMESTAMP')
})
}
Run the code above in your browser using DataLab