- replicate_exdf
An exdf object representing one CO2 response curve.
- best_fit_parameters
An exdf object representing best-fit parameters for the CO2 response
curve in replicate_exdf, as calculated by fit_c4_aci.
- lower
The same value that was passed to fit_c4_aci when generating
best_fit_parameters.
- upper
The same value that was passed to fit_c4_aci when generating
best_fit_parameters.
- fit_options
The same value that was passed to fit_c4_aci when generating
best_fit_parameters.
- sd_A
The same value that was passed to fit_c4_aci when generating
best_fit_parameters.
- relative_likelihood_threshold
The threshold value of relative likelihood used to define the boundaries of
the confidence intervals; see details below.
- x_etr
The fraction of whole-chain electron transport occurring in the mesophyll
(dimensionless). See Equation 29 from S. von Caemmerer (2021).
- a_column_name
The name of the column in replicate_exdf that contains the net
assimilation in micromol m^(-2) s^(-1).
- ao_column_name
The name of the column in replicate_exdf that contains the
dimensionless ratio of solubility and diffusivity of O2 to CO2.
- ci_column_name
The name of the column in replicate_exdf that contains the
intercellular CO2 concentration in micromol mol^(-1).
- gamma_star_column_name
The name of the column in replicate_exdf that contains the
dimensionless gamma_star values.
- gmc_norm_column_name
The name of the column in replicate_exdf that contains the normalized
mesophyll conductance values (with units of
normalized to gmc at 25 degrees C).
- j_norm_column_name
The name of the column in exdf_obj that contains the normalized
J values (with units of normalized to J at 25 degrees C).
- kc_column_name
The name of the column in replicate_exdf that contains the
Michaelis-Menten constant for rubisco carboxylation in microbar.
- ko_column_name
The name of the column in replicate_exdf that contains the
Michaelis-Menten constant for rubisco oxygenation in mbar.
- kp_column_name
The name of the column in replicate_exdf that contains the
Michaelis-Menten constant for PEP carboxylase carboxylation in
microbar.
- oxygen_column_name
The name of the column in exdf_obj that contains the concentration
of O2 in the ambient air, expressed as a percentage (commonly 21% or 2%);
the units must be percent.
- rl_norm_column_name
The name of the column in replicate_exdf that contains the normalized
RL values (with units of normalized to RL at 25 degrees C).
- total_pressure_column_name
The name of the column in exdf_obj that contains the total pressure
in bar.
- vcmax_norm_column_name
The name of the column in replicate_exdf that contains the normalized
Vcmax values (with units of
normalized to Vcmax at 25 degrees C).
- vpmax_norm_column_name
The name of the column in replicate_exdf that contains the normalized
Vpmax values (with units of
normalized to Vpmax at 25 degrees C).
- hard_constraints
To be passed to calculate_c4_assimilation; see that function
for more details.