# Example: Read data from a Licor log file and get the oxygen information from
# the preamble
# Read the file without automatically specifying oxygen units
licor_data <- read_gasex_file(
PhotoGEA_example_file_path('licor_for_gm_site11.xlsx'),
get_oxygen = FALSE
)
# Here we can see that the oxygen column is included, but without units
print(licor_data$categories$Oxygen)
print(licor_data$units$Oxygen)
print(licor_data[, 'Oxygen'])
# Include the oxygen units
licor_data <- get_oxygen_from_preamble(licor_data)
# The units have changed, but the category and values have not
print(licor_data$categories$Oxygen)
print(licor_data$units$Oxygen)
print(licor_data[, 'Oxygen'])
Run the code above in your browser using DataLab