Typically a TDL system periodically cycles between multiple gas lines during
measurements. Some of the gas lines represent gas mixtures with known
composition that can be used for calibration, while others are the "unknown"
mixtures whose composition is being measured. A collection of valves are used
to control which gas line is being measured at any given time, and the
"active" valve for each recorded data point is included in a measurement file.
When using the calibration lines to apply corrections to the measured data, it
is necessary to first identify complete measurements cycles within the data
set. Here, complete cycles are identified using the following criteria:
A cycle is said to begin when the value of valve_column_name is
cycle_start_valve.
A cycle ends after expected_cycle_num_valves valves have been
measured.
The time difference between the first and last points of a cycle
cannot deviate from expected_cycle_length_minutes by more than
+/- 30 seconds.
In addition to identifying valid measurement cycles within the data,
identify_tdl_cycles also calculates the elapsed time at the beginning
of each cycle (in minutes).
If no cycles are identified, the most likely explanation is that the values of
some of the key input arguments (such as cycle_start_valve,
expected_cycle_length_minutes, or expected_cycle_num_valves) may
be incorrect for the data in tdl_exdf. In this case, an error message
will be sent.